<?php
namespace PME\Modules\Planejamento\Prato;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;

class UtilizacaoProdutosController extends \PME\Services\TeknisaCrud {
	protected $crudService;
    protected $parameterBag;
    protected $Lista;
    protected $utilities;
    protected $connection;
    protected $environment;
    protected $receita;
    protected $qtdPessoa;

    public function __construct($crudService, $parameterBag, $Lista, $utilities, $connection, $environment, $receita, $qtdPessoa) {
        parent::__construct($crudService, $parameterBag);
        $this->Lista = $Lista;
        $this->utilities = $utilities;
        $this->connection = $connection;
        $this->environment = $environment;
        $this->receita = $receita;
        $this->qtdPessoa = $qtdPessoa;
    }
  
    public function retornaListaServ(DTO\Request $request, DTO\Response $response) {
        $nrorg = $this->utilities->getNrOrg();
        $rows = $request->getRow();
    
        $nrlistaserv = '';
        
        $tipoReceita = !empty($rows['TPRECEITA']) ? $rows['TPRECEITA'] : $rows['TPRECEITA1'];
        
        if (in_array('S', $tipoReceita)) {
            if(count($rows['SERVICO']) > 0) { 
              $servicos = $rows['SERVICO'];
            } else {
            //   $servicos = $this->getServicos($rows);
                $rowNew = array(
                  'CDFILIAL' => !empty(join("_", $rows['UNIDADE'])) ? join("_", $rows['UNIDADE']) : 'T',
                  'CDGRUPSERV' => 'T',
                  'CDGRUPFILI' => $rows['GRUPFILI'] ? $rows['GRUPFILI'] : 'T',
                  'CDFILCENTPME' => $rows['CDFILCENTPME'],
                  'IDTIPOSERV' => '',
                );
                $requestNew = new DTO\Request\Row($rowNew,'', '', '');
                $this->qtdPessoa->retornaServicosInd($requestNew, $response);
                if (count($response->getDataSets()) > 0)
                    $servicos = $response->getDataSets()[0]->getRows();
                else $servicos = array();
            }
            
            $unidadeServico = '';
            foreach($servicos as $servfili) {
              $unidadeServico .= $servfili['FILISERV'] . "_";
            }
            
            $nrlistaserv = $this->Lista->geraLista($unidadeServico, $nrorg);
        } else {
            if (in_array('L', $tipoReceita)) {
                if (count($rows['UNIDADE']) > 0) { 
                    $unidade = $rows['UNIDADE'];
                    $unidadeConcat = '';
                    foreach($unidade as $fil) {
                      $unidadeConcat .= $fil . "_";
                    }
                } else {
                    // $unidade = $this->getAgregadaCentralPAE($rows);
                    $unidade = $this->getUnidade($rows);
                  
                    $unidadeConcat = '';
                    foreach($unidade as $fil) {
                        $unidadeConcat .= $fil['CDFILIAL'] . "_";
                    }
                }
                $nrlistaserv = $this->Lista->geraLista($unidadeConcat, $nrorg);
            }
            
            if (in_array('T', $tipoReceita) and !$nrlistaserv) {
                if (count($rows['UNIDADE']) > 0) {
                    $unidade = array();
                    foreach ($rows['UNIDADE'] as $cd) {
                      $unidade[] = array("CDFILIAL" => $cd);
                    }
                } else {
                    $unidade = $this->getAgregadaCentralPAE($rows);      
                }
                  
                $unidadeConcat = '';
                foreach($unidade as $filiTp) {
                    $unidadeConcat .= $filiTp['CDFILIAL'] . "_";
                }
                
                $nrlistaserv = $this->Lista->geraLista($unidadeConcat, $nrorg);
            }
        }
	    $response->addDataSet(new DataSet("result", ["data"=> $nrlistaserv]));
	}
  
    public function getServicos($rows) {
        $dataSourceName = 'servicoPorUnidade';
        
        if (empty($rows['UNIDADE'])) $cdfilial = 'T';
        else {
          $unidadeRow = [];
          $cdfilial = join("_", $rows['UNIDADE']);
        }
        
        $conditions = array(
            array(
                'columnName' => 'CDFILIAL',
                'operator' => '=',
                'value' => $cdfilial
            )
        );
        
        $result = $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();
        
        return $result;
    }
    
    public function alteracaoAutomatica(DTO\Request\Row $request, DTO\Response $response) {
    	$this->connection->beginTransaction();
    	try {
    		$parameters = $request->getParameters();
    		$produtos = $parameters['produtos'];
            $valores = $parameters['values'];
            $qtAtiva = $parameters['QTATIVA'];
            
            $nrorg = $this->utilities->getNrOrg();
            $data = $this->environment->getCurrentTime();
            $operador = $this->environment->getCdOperador();
            
            foreach ($produtos as $produto) {
            	$tabela = $produto['NMTABLE'];
                $produtoIncl = $valores['CDPRODUTO'];
                
                if ($produtoIncl) {
                    $produtoMarcado = $produtoIncl;
                } else {
                    $produtoMarcado = $produto['CDPRODUTO'];
                }
                
                $prato = $produto['CDPRATO'];
                $filAuxPrato = $produto['CDFILAUXPRAT'];
                
                $qtLiq    = $qtBruta    = $qtReq = $ganho = $perda = 0;
                $aprovCoc = $aprovPerda = $aprovNutri = 100;
                $unidade  = $qtNutri    = $tempo = '';
                
                $vrdegelo = 0.0;
                $campoOpcao    = $valores['OPCAO'];
                
                switch ($tabela) {
                	case 'RECEPADR':
	                    // $produto = $this->retornaInformacoes(
	                    //     strtolower($tabela), $prato, $filAuxPrato, null, null, $produtoMarcado
	                    // );
	                    $prod = $this->receita->returnRecipePadrao($prato, $filAuxPrato, $produtoMarcado);
	                    if ($prod && count($prod) > 0 ) {
	                        $prod    = $prod[0];
	                        $unidade    = $prod['SGUNIDADE'];
	                        $qtLiq      = $prod['QTPRODPRAT'];
	                        $qtBruta    = $prod['QTBRUTAPRUNR'];
	                        $qtReq      = $prod['QTBRUTAPR'];
	                        $ganho      = $prod['VRPEFATCOCPR'];
	                        $aprovCoc   = $prod['VRPEFATCOCPR'] + 100;
	                        $perda      = $prod['VRPEFATCORPR'];
	                        $aprovPerda = 100 - $prod['VRPEFATCORPR'];
	                        $qtNutri    = $prod['QTCALCNUTRPR'];
	                        $aprovNutri = $prod['VRPEFATNUTPR'];
	                        $tempo      = $prod['HRTEMPPREPPR'];
	                        $vrdegelo   = $prod['VRPERCDEGELO'];
	                    } 
                    break;
                	case 'RECEFILI':
                		$prod = $this->receita->returnRecipeLocal($prato, $filAuxPrato, $produto['FILIAL'], $produtoMarcado);
                		if ($prod && count($prod) > 0 )  {
	                        $prod    = $prod[0];
	                        $unidade    = $prod['SGUNIDADE'];
	                        $qtLiq      = $prod['QTPRODRECLOC'];
	                        $qtBruta    = $prod['QTBRUTALOUNR'];
	                        $qtReq      = $prod['QTBRUTALO'];
	                        $ganho      = $prod['VRPEFATCOCLO'];
	                        $aprovCoc   = $prod['VRPEFATCOCLO'] + 100;
	                        $perda      = $prod['VRPEFATCORLO'];
	                        $aprovPerda = 100 - $prod['VRPEFATCORLO'];
	                        $qtNutri    = $prod['QTCALCNUTRLO'];
	                        $aprovNutri = $prod['VRPEFATNUTLO'];
	                        $tempo      = $prod['HRTEMPPREPLO'];
	                        $vrdegelo   = $prod['VRPERCDEGELO'];
	                    }
	                break;
	                case 'RECESERV':
	                	$prod = $this->receita->returnRecipeServico($prato, $filAuxPrato, $produto['FILIAL'], $produto['CDSERVFILI'], $produtoMarcado);
                		if ($prod && count($prod) > 0 )  {
                			$prod    = $prod[0];
	                        $unidade    = $prod['SGUNIDADE'];
	                        $qtLiq      = $prod['QTPRODRECSER'];
	                        $qtBruta    = $prod['QTBRUTASEUNR'];
	                        $qtReq      = $prod['QTBRUTASE'];
	                        $ganho      = $prod['VRPEFATCOCSE'];
	                        $aprovCoc   = $prod['VRPEFATCOCSE'] + 100;
	                        $perda      = $prod['VRPEFATCORSE'];
	                        $aprovPerda = 100 - $prod['VRPEFATCORSE'];
	                        $qtNutri    = $prod['QTCALCNUTRSE'];
	                        $aprovNutri = $prod['VRPEFATNUTSE'];
	                        $tempo      = $prod['HRTEMPPREPSE'];
	                        $vrdegelo   = $prod['VRPERCDEGELO'];
                		}
	                break;
	                case 'RECETPCARD':
	                	$prod = $this->receita->returnRecipeTpCard($prato, $filAuxPrato, $produto['CDTIPOCARD'], $produto['CDFILCENTPME'], $produtoMarcado);
                		if ($prod && count($prod) > 0 )  {
                			$prod    = $prod[0];
	                        $unidade    = $prod['SGUNIDADE'];
	                        $qtLiq      = $prod['QTPRODPRATTP'];
	                        $qtBruta    = $prod['QTBRUTAPRUNRTP'];
	                        $qtReq      = $prod['QTBRUTAPRTP'];
	                        $ganho      = $prod['VRPEFATCOCPRTP'];
	                        $aprovCoc   = $prod['VRPEFATCOCPRTP'] + 100;
	                        $perda      = $prod['VRPEFATCORPRTP'];
	                        $aprovPerda = 100 - $prod['VRPEFATCORPRTP'];
	                        $qtNutri    = $prod['QTCALCNUTRPRTP'];
	                        $aprovNutri = $prod['VRPEFATNUTPRTP'];
	                        $tempo      = $prod['HRTEMPPREPPRTP'];
	                        $vrdegelo   = $prod['VRPERCDEGELO'];
                		}
	                break;
                }
                
                if (!($prod && count($prod) > 0) && $campoOpcao == 'A')  {
                	$unidade    = $produto['SGUNIDADE'];
                    $qtLiq      = $produto['QTPRODPRAT'];
                    $qtBruta    = $produto['QTBRUTAPRUNR'];
                    $qtReq      = $produto['QTBRUTAPR'];
                    $ganho      = $produto['VRPEFATCOCPR'];
                    $aprovCoc   = $produto['VRPEFATCOCPRAP'];
                    $perda      = $produto['VRPEFATCORPR']; 
                    $aprovPerda = $produto['VRPEFATCORPRAP'];
                    $qtNutri    = $produto['QTCALCNUTRPR'];
                    $aprovNutri = $produto['VRPEFATNUTPR'];
                    $tempo      = $produto['HRTEMPPREPPR'];
                    $vrdegelo   = $produto['VRPERCDEGELO'];
                }
                
                $unAlt         = $valores['SGUNIDADE'];
                $ganhoAlt      = $valores['VRPEFATCOCPR'];
                $perdaAlt      = $valores['VRPEFATCORPR'];
                $tempoAlt      = $valores['HRTEMPPREPPR'];
                $fatConv       = $valores['VRFATOCONVES'];
                $qtLiqAlt      = $valores['QTPRODPRAT'];
                $qtBrutaAlt    = $valores['QTBRUTAPRUNR'];
                $aprovGanhoAlt = $valores['VRPEFATCOCPRAP'];
                $aprovPerdaAlt = $valores['VRPEFATCORPRAP'];
                $aprovNutrAlt  = $valores['VRPEFATNUTPR'];
                $vrdegeloAlt   = $valores['VRPERCDEGELO'];
                $formaAlteracao = $valores['FORMA'];
                
                if (empty($unAlt)) $unAlt = $unidade;
                
                if (empty($qtLiqAlt)) $qtLiqAlt = $qtLiq;
                
                if (empty($qtBrutaAlt)) $qtBrutaAlt = $qtBruta;
                
                // $valorQtdFormulario = 100;
                $valorQtdFormulario =  ($qtAtiva === 'L') ? $valores['QTBRUTAPRUNR'] : $valores['QTPRODPRAT']; 

                if ($valorQtdFormulario === 0) throw new \Exception('ERRO_QTD_ZERO');
                
                if ($formaAlteracao == 'P' && $valorQtdFormulario > 0) {
                    if ($qtAtiva === 'L') {
                        $qtBrutaAlt = round(($valorQtdFormulario * $produto['QTBRUTAPRUNR'])/100, 5);
                    } else {
                        $qtLiqAlt = round(($valorQtdFormulario * $produto['QTPRODPRAT'])/100, 5);
                    }
                }
                
                if (empty($ganhoAlt)) $ganhoAlt = $ganho;

                if (empty($aprovGanhoAlt)) $aprovGanhoAlt = $aprovCoc;

                if (empty($perdaAlt)) $perdaAlt = $perda;
                
                if (empty($aprovPerdaAlt)) $aprovPerdaAlt = $aprovPerda;
                
                if (empty($tempoAlt)) $tempoAlt = $tempo;
            
                if (empty($aprovNutrAlt) && $aprovNutrAlt !== 0) $aprovNutrAlt = $aprovNutri;

                if (empty($vrdegeloAlt) && $vrdegeloAlt !== 0) $vrdegeloAlt = $vrdegelo;
                
                $qtdeCalc = ($qtAtiva == 'B') ? $qtLiqAlt : $qtBrutaAlt;
                $qtdGanho = ($qtAtiva == 'L') ? round(($qtdeCalc * $aprovGanhoAlt) / 100, 5) : round(($qtdeCalc / $aprovGanhoAlt) * 100, 5);
                $qtdDegelo = ($qtAtiva == 'L') ? round(($qtdGanho *  100-$vrdegeloAlt) / 100, 5) : round(($qtdGanho / 100-$vrdegeloAlt) * 100, 5);
				$quantidadeFinal = ($qtAtiva == 'L') ? round(($qtdDegelo * $aprovPerdaAlt) / 100, 5) : round(($qtdDegelo / $aprovPerdaAlt) * 100, 5);
            	
            	if ($qtAtiva === 'L') {
                    $qtBruta = $qtBrutaAlt;
                    $qtLiq = $quantidadeFinal;
                } else {
                    $qtLiq = $qtLiqAlt;
                    $qtBruta = $quantidadeFinal;
                }
                
                $validaQtLiq = !empty($qtLiq) ? round($qtLiq, 5) : null;
                $validaQtBruta = !empty($qtBruta) ? round($qtBruta, 5) : null;
                
                if($validaQtLiq < 0.00001 || $validaQtBruta < 0.00001){
                    throw new \Exception('ERRO_QTD_LIMITE_MINIMO');
                }
                
                if (empty($fatConv)) $fatConv = $this->retornaFatorConversao($produtoMarcado, $unAlt)[0]["VRFATOCONVES"];   
                
                $qtUniDest = $qtReq = $qtBruta * $fatConv;
                // $qtCalcNutr = $qtBrutaAlt - ($qtReq * ($vrdegeloAlt / 100));
                $baseNutri = $qtReq - ($qtReq * ($perdaAlt / 100));
                $qtCalcNutr = ($baseNutri * $aprovNutrAlt) / 100;
                
                if (!$prod && $campoOpcao == 'I') { // insere
                    $prod = array();

                    $prod['CDPRODUTO'] = $produtoMarcado;
                    $prod['CDPRATO'] = $prato;
                    $prod['CDFILAUXPRAT'] = $filAuxPrato;
                    $prod['__is_new'] = true;
                } else $prod['__is_new'] = false;
                
                $novoProdutoJaNaReceita = false;
                
                // atualiza Dados
                switch ($tabela) {
                	case 'RECEPADR':
                		if ($valores['NMPRODUTO'] && $campoOpcao == 'A') {
                			$prod['CDPRODUTO'] = $valores['CDPRODUTO'];
	                        $prod['CDPRATO'] = $prato;
	                        $prod['CDFILAUXPRAT'] = $filAuxPrato;
	                        $prod['__is_new'] = false;
	                        
	                        $novoProdutoJaNaReceita = $this->receita->returnRecipePadrao($prato, $filAuxPrato, $prod['CDPRODUTO']);
                		}
                		
                		$prod['SGUNIDADE']    = $unAlt;
	                    $prod['QTPRODPRAT']   = $qtLiq;
	                    $prod['QTBRUTAPRUNR'] = $qtBruta;
	                    $prod['QTBRUTAPR']    = $qtReq;
	                    $prod['VRPEFATCOCPR'] = $ganhoAlt;
	                    $prod['VRPEFATCORPR'] = $perdaAlt;
	                    $prod['QTCALCNUTRPR'] = $qtCalcNutr;
	                    $prod['VRPEFATNUTPR'] = $aprovNutrAlt;
	                    $prod['QTUNIDESTPR']  = $qtUniDest;
	                    $prod['HRTEMPPREPPR'] = $tempoAlt;
	                    $prod['VRPERCDEGELO'] = $vrdegeloAlt;
                		
                	break;
                	case 'RECEFILI':
                		if ($valores['NMPRODUTO'] && $campoOpcao == 'A') {
                			$prod['CDPRODUTO'] = $valores['CDPRODUTO'];
	                        $prod['CDPRATO'] = $prato;
	                        $prod['CDFILAUXPRAT'] = $filAuxPrato;
	                        $prod['__is_new'] = false;
	                        
	                        $novoProdutoJaNaReceita = $this->receita->returnRecipeLocal($prato, $filAuxPrato, $produto['FILIAL'], $prod['CDPRODUTO']);
                		}
                		
                		$prod['SGUNIDADE']    = $unAlt;
	                    $prod['QTPRODRECLOC'] = $qtLiq;
	                    $prod['QTBRUTALOUNR'] = $qtBruta;
	                    $prod['QTBRUTALO']    = $qtReq;
	                    $prod['VRPEFATCOCLO'] = $ganhoAlt;
	                    $prod['VRPEFATCORLO'] = $perdaAlt;
	                    $prod['QTCALCNUTRLO'] = $qtCalcNutr;
	                    $prod['VRPEFATNUTLO'] = $aprovNutrAlt;
	                    $prod['QTUNIDESTLO']  = $qtUniDest;
	                    $prod['HRTEMPPREPLO'] = $tempoAlt;
	                    $prod['CDFILIAL']     = $produto['FILIAL'];
	                    $prod['VRPERCDEGELO'] = $vrdegeloAlt;
                		
                	break;
                	case 'RECESERV':
                		if ($valores['NMPRODUTO'] && $campoOpcao == 'A') {
                			$prod['CDPRODUTO'] = $valores['CDPRODUTO'];
	                        $prod['CDPRATO'] = $prato;
	                        $prod['CDFILAUXPRAT'] = $filAuxPrato;
	                        $prod['__is_new'] = false;
	                        
	                        $novoProdutoJaNaReceita = $this->receita->returnRecipeServico($prato, $filAuxPrato, $produto['FILIAL'], $produto['CDSERVFILI'], $prod['CDPRODUTO']);
                		}
                		
                		$prod['SGUNIDADE']    = $unAlt;
	                    $prod['QTPRODRECSER'] = $qtLiq;
	                    $prod['QTBRUTASEUNR'] = $qtBruta;
	                    $prod['QTBRUTASE']    = $qtReq;
	                    $prod['VRPEFATCOCSE'] = $ganhoAlt;
	                    $prod['VRPEFATCORSE'] = $perdaAlt;
	                    $prod['QTCALCNUTRSE'] = $qtCalcNutr;
	                    $prod['VRPEFATNUTSE'] = $aprovNutrAlt;
	                    $prod['QTUNIDESTSE']  = $qtUniDest;
	                    $prod['HRTEMPPREPSE'] = $tempoAlt;
	                    $prod['CDFILIAL']     = $produto['FILIAL'];
	                    $prod['CDSERVFILI']   = $produto['CDSERVFILI'];
	                    $prod['VRPERCDEGELO'] = $vrdegeloAlt;
                		
                	break;
                	case 'RECETPCARD':
                		if ($valores['NMPRODUTO'] && $campoOpcao == 'A') {
                			$prod['CDPRODUTO'] = $valores['CDPRODUTO'];
	                        $prod['CDPRATO'] = $prato;
	                        $prod['CDFILAUXPRAT'] = $filAuxPrato;
	                        $prod['__is_new'] = false;	
	                        
	                        $novoProdutoJaNaReceita = $this->receita->returnRecipeTpCard($prato, $filAuxPrato, $produto['CDTIPOCARD'], $produto['CDFILCENTPME'], $prod['CDPRODUTO']);
                		}
                		
                		$prod['SGUNIDADE']      = $unAlt;
	                    $prod['QTPRODPRATTP']   = $qtLiq;
	                    $prod['QTBRUTAPRUNRTP'] = $qtBruta;
	                    $prod['QTBRUTAPRTP']    = $qtReq;
	                    $prod['VRPEFATCOCPRTP'] = $ganhoAlt;
	                    $prod['VRPEFATCORPRTP'] = $perdaAlt;
	                    $prod['QTCALCNUTRPRTP'] = $qtCalcNutr;
	                    $prod['VRPEFATNUTPRTP'] = $aprovNutrAlt;
	                    $prod['QTUNIDESTPRTP']  = $qtUniDest;
	                    $prod['HRTEMPPREPPRTP'] = $tempoAlt;
	                    $prod['CDTIPOCARD']     = $produto['CDTIPOCARD'];
	                    $prod['CDFILCENTPME']   = $produto['CDFILCENTPME'];
	                    $prod['VRPERCDEGELO']   = $vrdegeloAlt;
                	break;
                }
                
                if ($novoProdutoJaNaReceita) throw new \Exception('ERRO_PROD_ALT_JA_EXISTE');
                
                if ($valores['NMPRODUTO'] && $campoOpcao == 'A' && $tabela == 'RECEPADR') {
                    $prodASubstituirPadrao = $produto['CDPRODUTO'];
                    $prodNovoPadrao = $valores['CDPRODUTO'];
                    
                    $update = array(
                    	'CDPRODUTO_OLD' => $prodASubstituirPadrao, 
                    	'CDPRODUTO_NEW' => $prodNovoPadrao,
                    	'CDFILAUXPRAT' => $filAuxPrato, 
                    	'CDPRATO' => $prato,
                    );
                    
                    $this->receita->updateRecipeProduct($tabela, $update);
                } else if ($valores['NMPRODUTO'] && $campoOpcao == 'A' && $tabela == 'RECEFILI') {
                    $prodASubstituirLocal = $produto['CDPRODUTO'];
                    $prodNovoLocal = $valores['CDPRODUTO'];
                    $prodFilial = $produto['FILIAL'];
                    
                    $update = array(
                    	'CDPRODUTO_OLD' => $prodASubstituirLocal, 
                    	'CDPRODUTO_NEW' => $prodNovoLocal,
                    	'CDFILAUXPRAT' => $filAuxPrato, 
                    	'CDPRATO' => $prato,
                    	'CDFILIAL' => $prodFilial,
                    );
                    
                    $this->receita->updateRecipeProduct($tabela, $update);
                } else if($valores['NMPRODUTO'] && $campoOpcao == 'A' && $tabela == 'RECESERV') {
                    $prodASubstituirServico = $produto['CDPRODUTO'];
                    $prodNovoServico = $valores['CDPRODUTO'];
                    $prodFilial = $produto['FILIAL'];
                    $prodCdservfili = $produto['CDSERVFILI'];
                    
                    $update = array(
                    	'CDPRODUTO_OLD' => $prodASubstituirServico, 
                    	'CDPRODUTO_NEW' => $prodNovoServico,
                    	'CDFILAUXPRAT' => $filAuxPrato, 
                    	'CDPRATO' => $prato,
                    	'CDFILIAL' => $prodFilial,
                    	'CDSERVFILI' => $prodCdservfili,
                    );
            
                    $this->receita->updateRecipeProduct($tabela, $update);
                } else if($valores['NMPRODUTO'] && $campoOpcao == 'A' && $tabela == 'RECETPCARD') {
                    $prodASubstituirTpCard = $produto['CDPRODUTO'];
                    $prodNovoTpCard = $valores['CDPRODUTO'];
                    $prodTpCard = $produto['CDTIPOCARD'];
                    $prodCdfilcentpme = $produto['CDFILCENTPME'];
                    
                    $update = array(
                    	'CDPRODUTO_OLD' => $prodASubstituirTpCard, 
                    	'CDPRODUTO_NEW' => $prodNovoTpCard,
                    	'CDFILAUXPRAT' => $filAuxPrato, 
                    	'CDPRATO' => $prato,
                    	'CDTIPOCARD' => $prodTpCard,
                    	'CDFILCENTPME' => $prodCdfilcentpme,
                    );
            
                    $this->receita->updateRecipeProduct($tabela, $update);
                }
                
                switch ($tabela) {
                	case 'RECEPADR':
                		// $prod['IDTPREQPRODPADR'] = "I";
                		$prod['IDTPREQPRODPADR'] = "P";
        						$prod['QTLIMSEGPADR'] = null;
        						$prod['IDUTCOMPENTDIRP'] = "N";
        						$prod['IDQTDEFIXPR'] = "N";
        						$prod['QTCOMPLPRODPADR'] = null;
        						$prod['IDPRODBASEPR'] = "N";
        						$prod['CDAPRERECE'] = null;
                		$this->receita->insertRecipeStandard($prod);
                		break;
                	case 'RECEFILI':
                	 // $prod['IDTPREQPRODFILI'] = "I";
                		$prod['IDTPREQPRODFILI'] = "P";
        						$prod['QTLIMSEGFILI'] = null;
        						$prod['IDUTCOMPENTDIRF'] = "N";
        						$prod['IDQTDEFIXLO'] = "N";
        						$prod['QTCOMPLPRODFILI'] = null;
        						$prod['IDPRODBASELO'] = "N";
        						$prod['CDAPRERECE'] = null;
                		$this->receita->insertRecipeLocal($prod);
                		break;
                	case 'RECESERV':
                	 // $prod['IDTPREQPRODSERV'] = "I";
                		$prod['IDTPREQPRODSERV'] = "P";
        						$prod['QTLIMSEGSERV'] = null;
        						$prod['IDUTCOMPENTDIRS'] = "N";
        						$prod['IDQTDEFIXSE'] = "N";
        						$prod['QTCOMPLPRODSERV'] = null;
        						$prod['IDPRODBASESE'] = "N";
        						$prod['CDAPRERECE'] = null;
                		$this->receita->insertRecipeService($prod);
                		break;
                	case 'RECETPCARD':
                		$prod['IDQTDEFIXPRTP'] = "N";
        						$prod['IDPRODBASEPRTP'] = "N";
        						$prod['CDAPRERECE'] = null;
                		$this->receita->insertRecipeTpCard($prod);
                		break;
                }
            }
            
    		$this->connection->commit();
	        $response->addDataset(new DataSet('RETORNO', array(true)));
    	} catch (\Exception $e) {
    		  $this->connection->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function retornaFatorConversao($produto, $sgunidade){
        $sql = "SELECT DISTINCT SGUNIDADE, VRFATOCONVES, CDPRODUTO, NRORG
                  FROM (SELECT SGUNIDADE, VRFATOCONVES, CDPRODUTO, NRORG
                          FROM CONVPRODUTO
                         WHERE CDPRODUTO = :CDPRODUTO
                           AND NRORG     = :NRORG
                           AND SGUNIDADE = :SGUNIDADE
                         UNION ALL
                        SELECT SGUNIDPARA         AS SGUNIDADE,
                               TO_NUMBER(VRFTCONVER) AS VRFATOCONVES,
                               :CDPRODUTO            AS CDPRODUTO,
                               NRORG
                          FROM CONVUNID
                         WHERE SGUNIDDE = :SGUNIDADE
                           AND NRORG        = :NRORG
                           AND SGUNIDPARA <> :SGUNIDADE
                         UNION ALL
                        SELECT :SGUNIDADE          AS SGUNIDADE,
                               TO_NUMBER(1) AS VRFATOCONVES,
                               :CDPRODUTO               AS CDPRODUTO,
                               TO_NUMBER(:NRORG)        AS NRORG
                          FROM PARAMGERAL
                      ) CONVPRODUTO";
		
        $params = array(
            "CDPRODUTO" => $produto,
            "SGUNIDADE" => $sgunidade,
            "NRORG" => $this->utilities->getNrOrg(),
        );

        try {
            return $this->connection->fetchAll($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    private function getUnidade($rows){
        $dataSourceName = 'unidadePorAgrup';
        
        $conditions = array(
            array(
                'columnName' => 'P_CDGRUPFILI',
                'operator' => '=',
                'value' => $rows['GRUPFILI'] ? $rows['GRUPFILI'] : 'T',
            )
        );
    
        $result = $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();
        return $result;
    }
    
    private function getAgregadaCentralPAE($rows){
        // $dataSourceName = 'agregadaPorCentral';
        $dataSourceName = 'agregadaPorCentralAgrup';
        
        $conditions = array(
            array(
                'columnName' => 'CDFILCENTPME',
                'operator' => '=',
                'value' => $rows['CDFILCENTPME'] 
            ),
             array(
                'columnName' => 'CDGRUPFILI',
                'operator' => '=',
                'value' => $rows['GRUPFILI'] ? $rows['GRUPFILI'] : 'T'
            )
        );
        $result = $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();
        return $result;
    }
}